@@ -296,7 +296,7 @@ class IRCBackendProtocol(twisted.words.protocols.irc.IRCClient):
         if user == "NickServ!NickServ@services.":
             nick, commands, result = msg.split(None, 2)
 
-            uri = self.factory.parent.config.get('fmn.sqlalchemy.uri'))
+            uri = self.factory.parent.config.get('fmn.sqlalchemy.uri')
             s = fmn.lib.models.init(uri)
 
             if result.strip() == '3':
